@@ -238,7 +238,7 @@ void CDesktop::drawDesktop(QPainter *p)
     QRectF frequency = renderer->boundsOnElement("Station_Freq");
 
     if ((frequency.height() == 0) &&  (frequency.width() == 0))
-        p->drawText(frequency.x(), frequency.y(), QString("%1").arg( CFMRadio::self().getFrequency()/1000 ));
+        p->drawText(frequency.x(), frequency.y(), QString("%1 Mhz").arg( CFMRadio::self().getFrequency()/1000 ));
     else
         p->drawText(frequency,  QString("%1 Mhz").arg( CFMRadio::self().getFrequency()/1000) );
 
