@@ -19,10 +19,12 @@ class CDlgSetup : public QDialog, private Ui::IDlgSetup
 	private slots:
 	    void slotCallSetup();
 	    void slotMP3Setup();
-	    void slotMainSetup();
+            void slotSmsSetup();
+            void slotMainSetup();
 	    void slotMafwActivate(int status);
 	    void slotRTComActivate(int status);
-			    
+            void slotSmsActivate(int status);
+
 };
 #endif
 	    
