@@ -29,7 +29,7 @@ CRdsBroadcast::CRdsBroadcast(QObject * parent)
 ,display(8)
 ,withDBus(true)
 ,endTime(30000)
-,defText("RDS Linux")
+,defText("Maemo FM")
 {
    m_self=this;
    QSettings cfg;
