@@ -18,7 +18,7 @@ CSms::CSms(QObject * parent)
     format = cfg.value("display/sms/format", format).toString();
     timeout = cfg.value("display/sms/timeout", timeout).toInt();
     state = cfg.value("main/sms", state).toBool();
-    connect = false;
+    bConnect = false;
 }
 
 CSms::~CSms()
@@ -52,9 +52,9 @@ int CSms::getTimeout()
 void CSms::setEnable(bool value)
 {
     if (value) {
-        value = QDBusConnection::systemBus().connect( 0, SMS_CSD_PATH, SMS_CSD_IF,  "MessageReceived", this, SLOT(slotComingChanged(QString,uint,QString,QString,QString,QDBusVariant)));
+        value = QDBusConnection::sessionBus().connect( 0, SMS_CSD_PATH, "org.freedesktop.Telepathy.Connection.Interface.Requests",  "NewChannels", this, SLOT(slotNotify(QList<QVariant>)));
     } else {
-       QDBusConnection::systemBus().disconnect( 0, SMS_CSD_PATH, SMS_CSD_IF,  "MessageReceived", this, SLOT(slotComingChanged(QString,uint,QString,QString,QString,QDBusVariant)));
+       QDBusConnection::sessionBus().disconnect( 0, SMS_CSD_PATH, SMS_CSD_IF_CON,  "NewChannel", this, SLOT(slotComingChanged(QDBusObjectPath, QString,uint,uint,bool)));
     }
     state = value;
     qDebug() << "Connected is " << value;
@@ -62,7 +62,7 @@ void CSms::setEnable(bool value)
 
 bool CSms::getEnable()
 {
-    return state && connect;
+    return state && bConnect;
 }
 
 bool CSms::getState()
@@ -70,17 +70,23 @@ bool CSms::getState()
     return state;
 }
 
-void CSms::slotComingChanged(QString ukn,uint id,QString type,QString from ,QString text,QDBusVariant var)
+void CSms::slotComingChanged(QDBusObjectPath objPath, QString channel,uint ukn,uint num,bool act)
+{
+    bool state = QDBusConnection::sessionBus().connect( 0, objPath.path(), channel, "Received", this, SLOT(slotTextReceived(uint ,uint ,uint , uint , uint ,QString )));
+    qDebug() << "path=" << objPath.path() << " channel=" << channel << " connected=" << state;
+}
+
+void CSms::slotTextReceived(uint ukn,uint time,uint chan, uint ukn2, uint ukn3,QString text)
 {
     smsText.clear();
     smsText.append(format);
 
-    smsText.replace("%name%", from);
+    smsText.replace("%name%", "");
     smsText.replace("%message%",text);
 
     sendText(smsText);
 
-    qDebug() << "Sms status received " << from;
+    qDebug() << "Sms status received " << smsText;
 }
 
 void CSms::sendText(QString text)
@@ -95,7 +101,14 @@ void CSms::setConnect(int value)
     if (value)
         setEnable(state);
     else {
-        QDBusConnection::systemBus().disconnect( 0, SMS_CSD_PATH, SMS_CSD_IF,  "MessageReceived", this, SLOT(slotComingChanged(QString,uint,QString,QString,QString,QDBusVariant)));
+        QDBusConnection::systemBus().disconnect( 0, SMS_CSD_PATH, SMS_CSD_IF_CON,  "NewChannel", this, SLOT(slotComingChanged(QDBusObjectPath, QString,uint,uint,bool)));
     }
-    connect = value;
+    bConnect = value;
+}
+
+void CSms::slotNotify(QList<QVariant> var)
+{
+    qDebug() << "slotNotify=" << var.at(0).typeName();
+    QDBusObjectPath objPath = qVariantValue<QDBusObjectPath>(var.at(0));
+    QDBusConnection::sessionBus().connect( 0, objPath.path(), "org.freedesktop.Telepathy.Channel.Type.Text", "Received", this, SLOT(slotTextReceived(uint ,uint ,uint , uint , uint ,QString )));
 }
