@@ -45,10 +45,12 @@ private:
     // Pluig status
     bool state;
     // Tx connect state
-    bool connect;
+    bool bConnect;
 
 private slots:
-    void slotComingChanged(QString ukn,uint id,QString type,QString from ,QString text,QDBusVariant var);
+    void slotNotify(QList<QVariant> var);
+    void slotComingChanged(QDBusObjectPath objPath, QString channel,uint ukn,uint num,bool act);
+    void slotTextReceived(uint ukn,uint time,uint chan, uint ukn2, uint ukn3,QString text);
 
 };
 
